@@ -5,7 +5,7 @@ use 5.006;
 use warnings;
 
 
-our $VERSION = '0.055'; # TRIAL VERSION
+our $VERSION = '0.056'; # TRIAL VERSION
 
 use utf8;
 use open ':std', ':utf8';
@@ -151,7 +151,7 @@ sub _manifest_md5 {
     my($self, $bagit) = @_;
     my $manifest_file = "$bagit/manifest-md5.txt";
     my $data_dir = "$bagit/data";
-    print "creating manifest: $data_dir\n";
+    #print "creating manifest: $data_dir\n";
     # Generate MD5 digests for all of the files under ./data
     open(my $md5_fh, ">:encoding(utf8)",$manifest_file) or die("Cannot create manifest-md5.txt: $!\n");
     find(
@@ -391,7 +391,7 @@ Archive::BagIt
 
 =head1 VERSION
 
-version 0.055
+version 0.056
 
 =head1 WARNING
 
