@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent "Archive::BagIt";
 
-our $VERSION = '0.055'; # TRIAL VERSION
+our $VERSION = '0.056'; # TRIAL VERSION
 
 use IO::AIO;
 use Time::HiRes qw(time);
@@ -28,7 +28,7 @@ sub verify_bag {
     die("$payload_dir is not a directory") unless -d ($payload_dir);
     # Read the manifest file
     #print Dumper($self->{entries});
-    foreach my $entry (keys( @{$self->{entries}})) {
+    foreach my $entry (keys %{$self->{entries}}) {
       $manifest{$entry} = $self->{entries}->{$entry};
     }
     # Compile a list of payload files
@@ -100,7 +100,7 @@ Archive::BagIt::Fast
 
 =head1 VERSION
 
-version 0.055
+version 0.056
 
 =head1 NAME
 
