@@ -21,20 +21,16 @@ after BUILD => sub {
 };
 
 sub verify_file {
-
 }
 
 sub verify {
-
 }
 
 sub manifest {
-
 }
 
 sub create_manifest {
     my ($self) = @_;
-
     my $algo = $self->algorithm->name;
     my $manifest_file = $self->bagit->metadata_path."/manifest-${algo}.txt";
     # Generate digests for all of the files under ./data
@@ -47,35 +43,34 @@ sub create_manifest {
         #print "lineout: $digest $filename\n";
     }
     close($fh);
+    return 1;
 
 }
 
 sub create_tagmanifest {
-  my ($self) = @_;
-
+    my ($self) = @_;
     my $algo = $self->algorithm->name;
-    my $tagmanifest_file= $self->bagit->metadata_path."/tagmanifest-${algo}.txt";
-
-    open (my $fh, ">", $tagmanifest_file) or die ("Cannot create tagmanifest-${algo}.txt: $! \n");
-
+    my $tagmanifest_file = $self->bagit->metadata_path . "/tagmanifest-${algo}.txt";
+    open(my $fh, ">", $tagmanifest_file) or die("Cannot create tagmanifest-${algo}.txt: $! \n");
     foreach my $rel_nonpayload_file (@{$self->bagit->non_payload_files}) {
         my $nonpayload_file = File::Spec->catdir($self->bagit->bag_path, $rel_nonpayload_file);
-        if ($rel_nonpayload_file=~m/tagmanifest-.*\.txt$/) {
+        if ($rel_nonpayload_file =~ m/tagmanifest-.*\.txt$/) {
             # Ignore, we can't take digest from ourselves
         }
-        elsif ( -f $nonpayload_file ) { # non-payload is all which is not payload, this allows user to define and handle own subdirs
-            my $digest = $self->algorithm->verify_file( $nonpayload_file );
+        elsif (-f $nonpayload_file) {
+            # non-payload is all which is not payload, this allows user to define and handle own subdirs
+            my $digest = $self->algorithm->verify_file($nonpayload_file);
             print($fh "$digest  $rel_nonpayload_file\n");
         }
         else {
             die("A file or directory that doesn't match: $rel_nonpayload_file");
         }
     }
-
-  close($fh);
+    close($fh);
+    return 1;
 }
 
-
+no Moose;
 1;
 
 __END__
@@ -90,7 +85,7 @@ Archive::BagIt::Role::Manifest
 
 =head1 VERSION
 
-version 0.054
+version 0.056
 
 =head1 AVAILABILITY
 
