@@ -23,8 +23,9 @@ sub BUILD {
     my ($self) = @_;
     my $plugin_name = $self->plugin_name;
     $self->bagit->plugins( { $plugin_name => $self });
+    return 1;
 }
-
+no Moose;
 1;
 
 __END__
@@ -39,7 +40,7 @@ Archive::BagIt::Role::Plugin
 
 =head1 VERSION
 
-version 0.054
+version 0.056
 
 =head1 AVAILABILITY
 
